package at.ac.uibk.gitsearch.web.rest;


import java.io.File;
import java.io.FileInputStream;
import java.io.FileNotFoundException;
import java.io.IOException;
import java.util.List;
import java.util.Optional;

import org.codeability.sharing.plugins.api.search.SearchResultDTO;
import org.codeability.sharing.plugins.api.search.SearchResultsDTO;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.core.io.InputStreamResource;
import org.springframework.core.io.Resource;
import org.springframework.http.MediaType;
import org.springframework.http.ResponseEntity;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

import at.ac.uibk.gitsearch.es.model.DocumentInfo;
import at.ac.uibk.gitsearch.service.AchievementService;
import at.ac.uibk.gitsearch.service.SearchService;
import at.ac.uibk.gitsearch.service.StatisticsService;
import at.ac.uibk.gitsearch.service.UserService;
import at.ac.uibk.gitsearch.service.dto.AutoCompleteEntry;
import at.ac.uibk.gitsearch.service.dto.StatisticsDTO;
import at.ac.uibk.gitsearch.web.util.HeaderUtil;

import org.springframework.http.HttpStatus;



@RestController
@RequestMapping("/api")
@Transactional
public class AchievementResource {
    

	private final static String applicationName = "gitsearchApp";

    private static final String ENTITY_NAME = "AchievementResource";

    private final Logger log = LoggerFactory.getLogger(SearchResource.class);

    private final SearchService searchService;

    private final AchievementService achievementService;

    private final StatisticsService statisticsService;

    private final UserService userService;


    public AchievementResource(SearchService searchService, StatisticsService statisticsService, UserService userService, AchievementService achievementService) {
        this.searchService = searchService;
        this.statisticsService = statisticsService;
        this.userService = userService;
        this.achievementService = achievementService;
    }

    @GetMapping("/user/achievements")
    @PreAuthorize("hasAnyRole('USER')")
    public ResponseEntity<StatisticsDTO> searchUserStatistics() throws IOException {
        String email = userService.getUserWithAuthorities().get().getEmail();
        log.debug("REST request to search statistics for user {}", email);
        StatisticsDTO toReturn = achievementService.searchUserStatistics(email);
        return new ResponseEntity<StatisticsDTO>(toReturn, HttpStatus.OK);
    
    
    }
}
